@@ -11,6 +11,10 @@ def __print_err__(text):
 @click.command()
 @click.argument('url', default=None)
 def main(url):
+    if url is None:
+        __print_err__('You must provide the RCP url of a Tendermint full-node \nEg: python download_genesis.py '
+                      'https://evmos-rpc.evmosis.com or https://evmos-rpc.polkachu.com')
+
     try:
         download_genesis(url)
     except (InvalidRPC, NodeNotSynchronized, UnsuccessfulHttpRequest) as e:
